
#define MFX_INIT 1

#include "testmfx.h"

